pub struct AccessLogEntryCreateInfo {
pub write_context: String,
}Expand description
AccessLogEntryCreateInfo : information available if the operation is of type "create".
Fields
write_context: StringAn identifier for a write context that might be imported from a peer domain. If it is, it will bear an imported resource prefix (either a domain identifier or an alias, followed by ::)
Implementations
sourceimpl AccessLogEntryCreateInfo
impl AccessLogEntryCreateInfo
sourcepub fn new(write_context: String) -> AccessLogEntryCreateInfo
pub fn new(write_context: String) -> AccessLogEntryCreateInfo
information available if the operation is of type "create".