pub struct ActiveRootEncryptionKeyId {
pub key_id: String,
pub rotate_batch: Option<bool>,
}Expand description
ActiveRootEncryptionKeyId : The stored key ID to use as the active root encryption key.
Fields
key_id: StringA UUID used for identifying root encryption keys.
rotate_batch: Option<bool>Indicates whether a batch of key encryption keys should be immediately rotated upon successful activation of the supplied root encryption key.
Implementations
sourceimpl ActiveRootEncryptionKeyId
impl ActiveRootEncryptionKeyId
sourcepub fn new(key_id: String) -> ActiveRootEncryptionKeyId
pub fn new(key_id: String) -> ActiveRootEncryptionKeyId
The stored key ID to use as the active root encryption key.