Struct antimatter_api::models::capability_rule::CapabilityRule
source · pub struct CapabilityRule {
pub match_expressions: Option<Vec<CapabilityRuleMatchExpressionsInner>>,
}Expand description
CapabilityRule : A rule that refers to a domain identity capability. These rules are ANDed together
Fields
match_expressions: Option<Vec<CapabilityRuleMatchExpressionsInner>>A list of capability matching patterns. Elements are ANDed together
Implementations
sourceimpl CapabilityRule
impl CapabilityRule
sourcepub fn new() -> CapabilityRule
pub fn new() -> CapabilityRule
A rule that refers to a domain identity capability. These rules are ANDed together