pub struct DomainFactList {
pub fact_types: Vec<FactTypeDefinition>,
}Expand description
DomainFactList : A list of defined fact types in the domain
Fields
fact_types: Vec<FactTypeDefinition>Implementations
Sourceimpl DomainFactList
impl DomainFactList
Sourcepub fn new(fact_types: Vec<FactTypeDefinition>) -> DomainFactList
pub fn new(fact_types: Vec<FactTypeDefinition>) -> DomainFactList
A list of defined fact types in the domain