pub struct ReadContextRuleMatchExpressionsInner {
pub source: Source,
pub key: String,
pub operator: Operator,
pub values: Option<Vec<String>>,
pub value: Option<String>,
}Fields
source: Sourcekey: Stringoperator: OperatorWhat to do with the value identified by key. In and NotIn compare with values, DateDeltaLessThan and DateDeltaGreaterThan treat the value as an RFC3339 date, and measure if the now()-date is less than or greater than the time span expressed in value.
values: Option<Vec<String>>to be used with In and NotIn operators
value: Option<String>To be used with DateDelta operators. A time span in 23d4h5m32s notation. It does not support interval shorthands greater than a day, so to express 3 months, for example, use 90d. Positive time spans indicate the date appeared in the past. Negative time spans indicate the date appears in the future.
Implementations