pub struct WriteContextConfigInfo {
pub key_reuse_ttl: Option<i32>,
pub default_capsule_tags: Option<Vec<WriteContextClassifierTag>>,
pub required_hooks: Vec<WriteContextConfigInfoRequiredHooksInner>,
}Expand description
WriteContextConfigInfo : Information about write context config rules
Fields
key_reuse_ttl: Option<i32>Number of seconds for which the client may reuse a given encryption key for sealing multiple capsules
required_hooks: Vec<WriteContextConfigInfoRequiredHooksInner>Implementations
sourceimpl WriteContextConfigInfo
impl WriteContextConfigInfo
sourcepub fn new(
required_hooks: Vec<WriteContextConfigInfoRequiredHooksInner>,
) -> WriteContextConfigInfo
pub fn new( required_hooks: Vec<WriteContextConfigInfoRequiredHooksInner>, ) -> WriteContextConfigInfo
Information about write context config rules