pub struct NewAccessLogEntryReadInfo {
pub parameters: HashMap<String, String>,
pub allowed_tags: Box<TagSummary>,
pub redacted_tags: Box<TagSummary>,
pub tokenized_tags: Box<TagSummary>,
pub returned_records: i32,
pub filtered_records: i32,
}Expand description
NewAccessLogEntryReadInfo : information available if the operation is of type "read". allowedTags are those that were allowed without transformation during the read. redactedTags are those that were redacted during the read. tokenizedTags are those that were tokenized during the read.
Fields
parameters: HashMap<String, String>the client-specified parameters representing the user on whose behalf this read is being carried out. Valid only for operation = read
returned_records: i32the number of records returned by the read, including those with allowed, redacted or tokenized spans
filtered_records: i32the number of records that were completely filtered out during the read operation
Implementations
Sourceimpl NewAccessLogEntryReadInfo
impl NewAccessLogEntryReadInfo
Sourcepub fn new(
parameters: HashMap<String, String>,
allowed_tags: TagSummary,
redacted_tags: TagSummary,
tokenized_tags: TagSummary,
returned_records: i32,
filtered_records: i32,
) -> NewAccessLogEntryReadInfo
pub fn new( parameters: HashMap<String, String>, allowed_tags: TagSummary, redacted_tags: TagSummary, tokenized_tags: TagSummary, returned_records: i32, filtered_records: i32, ) -> NewAccessLogEntryReadInfo
information available if the operation is of type "read". allowedTags are those that were allowed without transformation during the read. redactedTags are those that were redacted during the read. tokenizedTags are those that were tokenized during the read.